rotate_crs: Rotate CRS

View source: R/internal_functions.R

rotate_crsR Documentation

Rotate CRS

Description

Rotates a CRS such that North is in the middle of two meridians

Usage

rotate_crs(crs, meridians)

Arguments

crs

The CRS to be rotated in st_crs format

meridians

A numeric vector giving the two meridians which should be used in the rotation

Value

Rotated CRS in st_crs format

Author(s)

Mikko Vihtakari


ggOceanMaps documentation built on June 22, 2026, 5:07 p.m.