Internal function to load large shapefile objects. Downloads the files if they are not found getOption("ggOceanMaps.datapath")
Arguments
- x
An object from
shapefile_list.- force
Logical indicating whether to download the file even though it exists. Useful when files in the Github repository have been changed. Overwrites the old file.
- downsample
Integer defining the downsampling rate for raster bathymetries. A value of 0 (default) does not downsample, 1 skips every second row, 2 every second and third. See
geom_stars
Details
This is an internal function, which is automatically run by the basemap function. Common users do not need to worry about these details.